@@ -2,7 +2,7 @@
     Flowblade Movie Editor is a nonlinear video editor.
     Copyright 2012 Janne Liljeblad.
 
-    This file is part of Flowblade Movie Editor <http://code.google.com/p/flowblade>.
+    This file is part of Flowblade Movie Editor <https://github.com/jliljebl/flowblade/>.
 
     Flowblade Movie Editor is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -96,7 +96,7 @@ RIGHT_CHANNEL = "_audio_level.1"
 
 MONITORING_AVAILABLE = False
 
-# GUI compoents displaying levels
+# GUI components displaying levels
 _monitor_window = None
 _master_volume_meter = None
 
@@ -209,8 +209,7 @@ def get_master_meter():
     
     frame = Gtk.Frame()
     frame.add(align)
-    frame.set_shadow_type(Gtk.ShadowType.ETCHED_OUT)
-    guiutils.set_margins(frame, 0, 0, 1, 0)
+    guiutils.set_margins(frame, 0, 0, 1, 1)
     return frame
 
 def close_master_meter():
@@ -242,7 +241,7 @@ def _init_level_filters(create_track_filters):
     # so when Sequence is saved these filters will automatically be removed.
     # Filters are not part of sequence.Sequence object because they just used for monitoring,
     #
-    # Track/master gain values are persistant, they're also editing desitions 
+    # Track/master gain values are persistent, they're also editing decisions 
     # and are therefore part of sequence.Sequence objects.
     
     # Create levels filters array if it deosn't exist
@@ -414,10 +413,7 @@ class MetersArea:
     def _draw(self, event, cr, allocation):
         x, y, w, h = allocation
 
-        if editorpersistance.prefs.theme == appconsts.LIGHT_THEME:
-            cr.set_source_rgb(*METER_BG_COLOR)
-        else:
-            cr.set_source_rgb(0.0, 0.0, 0.0)
+        cr.set_source_rgb(0.0, 0.0, 0.0)
         cr.rectangle(0, 0, w, h)
         cr.fill()
 
@@ -692,10 +688,7 @@ class MasterVolumeMeter:
 
         self.meter.set_height(h - self.H_CUT)
  
-        if editorpersistance.prefs.theme == appconsts.LIGHT_THEME:
-            cr.set_source_rgb(*METER_BG_COLOR)
-        else:
-            cr.set_source_rgb(0.0, 0.0, 0.0)
+        cr.set_source_rgb(0.0, 0.0, 0.0)
         cr.fill_preserve()
         cr.rectangle(0, 0, w, h)
         cr.fill()
