@@ -2,7 +2,7 @@
     Flowblade Movie Editor is a nonlinear video editor.
     Copyright 2012 Janne Liljeblad.
 
-    This file is part of Flowblade Movie Editor <http://code.google.com/p/flowblade>.
+    This file is part of Flowblade Movie Editor <https://github.com/jliljebl/flowblade/>.
 
     Flowblade Movie Editor is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -37,8 +37,10 @@ from editorstate import current_sequence
 import fluxity
 import gui
 import guicomponents
+import guipopover
 import guiutils
 import mltprofiles
+import positionbar
 import respaths
 import simpleeditors
 import toolsencoding
@@ -46,7 +48,7 @@ import translations
 import userfolders
 import utils
 
-MONITOR_WIDTH = 400
+MONITOR_WIDTH = 500
 MONITOR_HEIGHT = -1
 PREVIEW_WIDTH = 320
 
@@ -56,7 +58,6 @@ _plugins = []
 _plugins_groups = []
 
 _add_plugin_window = None
-_plugins_menu = Gtk.Menu()
 
 _selected_plugin = None
 _current_screenshot_surface = None
@@ -153,11 +154,10 @@ def _get_categories_list():
     return categories_list  
 
 # This method is used by scriptool.py create sub menu to load generator code into 
-# editor window as an exemple.
+# editor window as an example.
 def fill_media_plugin_sub_menu_gio(app, menu, callback):
     for group_data in _plugins_groups:
         group_name, group = group_data
-        print("group_name", group_name)
         group_name_translated = translations.get_plugin_group_name(group_name)
         sub_menu = Gio.Menu.new()
         menu.append_submenu(group_name_translated, sub_menu)
@@ -174,12 +174,13 @@ def fill_media_plugin_sub_menu_gio(app, menu, callback):
 def _add_media_plugin():
     script_file = _selected_plugin.get_plugin_script_file()
     md_str = hashlib.md5(str(os.urandom(32)).encode('utf-8')).hexdigest()
-    screenshot_file = userfolders.get_cache_dir() + appconsts.THUMBNAILS_DIR + "/" + md_str +  ".png"
+    screenshot_file = userfolders.get_thumbnail_dir() + md_str +  ".png"
     fctx = _add_plugin_window._render_preview(int(_add_plugin_window.length_spin.get_value()/2))
     fctx.priv_context.frame_surface.write_to_png(screenshot_file)
     _current_plugin_data_object["editors_list"] = simpleeditors.get_editors_data_as_editors_list(_add_plugin_window.plugin_editors.editor_widgets)
     _current_plugin_data_object["length"] = int(_add_plugin_window.length_spin.get_value())
-
+    _current_plugin_data_object["groups_list"] = fctx.groups
+    
     if _add_plugin_window.import_select.get_active() == 0:
         _close_window()
         # Add as Container Clip
@@ -213,7 +214,7 @@ def _clone_properties_callback(dialog, response_id, data, length_spin, name_entr
         name = clip.name
 
     md_str = hashlib.md5(str(os.urandom(32)).encode('utf-8')).hexdigest()
-    screenshot_file = userfolders.get_cache_dir() + appconsts.THUMBNAILS_DIR + "/" + md_str +  ".png"
+    screenshot_file = userfolders.get_thumbnail_dir() + md_str +  ".png"
 
     script_file = open(old_cd.program)
     user_script = script_file.read()
@@ -231,7 +232,7 @@ def _clone_properties_callback(dialog, response_id, data, length_spin, name_entr
 
 def create_plugin_assests_for_media_import(old_cd):
     md_str = hashlib.md5(str(os.urandom(32)).encode('utf-8')).hexdigest()
-    screenshot_file = userfolders.get_cache_dir() + appconsts.THUMBNAILS_DIR + "/" + md_str +  ".png"
+    screenshot_file = userfolders.get_thumbnail_dir() + md_str +  ".png"
 
     new_length = old_cd.unrendered_length
     
@@ -259,6 +260,9 @@ def get_plugin_script_path(plugin_folder_and_script):
 class AddMediaPluginWindow(Gtk.Window):
     def __init__(self):
         GObject.GObject.__init__(self)
+        
+        self.producer = PosBarProducer()
+        
         self.set_modal(True)
         self.set_transient_for(gui.editor_window.window)
         self.set_title(_("Add Generator"))
@@ -283,37 +287,56 @@ class AddMediaPluginWindow(Gtk.Window):
         global MONITOR_HEIGHT
         MONITOR_HEIGHT = int(MONITOR_WIDTH * float(current_sequence().profile.display_aspect_den()) / float(current_sequence().profile.display_aspect_num()))
         self.screenshot_canvas = cairoarea.CairoDrawableArea2(MONITOR_WIDTH, MONITOR_HEIGHT, self._draw_screenshot)
-        screenshot_row = guiutils.get_centered_box([self.screenshot_canvas ])
-        guiutils.set_margins(screenshot_row, 0, 8, 0, 0)
+        guiutils.set_margins(self.screenshot_canvas, 0, 8, 0, 0)
 
         self.frame_display = Gtk.Label(label=_("Clip Frame"))
-        self.frame_display.set_margin_right(2)
+        self.frame_display.set_margin_end(2)
         
         self.frame_select = Gtk.SpinButton.new_with_range (0, 200, 1)
         self.frame_select.set_value(0)
         
         self.preview_button = Gtk.Button(label=_("Preview"))
         self.preview_button.connect("clicked", lambda w: self._show_preview())
-                            
+
+        # Control row
+        self.tc_display = guicomponents.MonitorTCDisplay(56)
+        self.tc_display.use_internal_frame = True
+        self.tc_display.widget.set_valign(Gtk.Align.CENTER)
+        self.tc_display.use_internal_fps = True
+        self.tc_display.display_tc = False
+        
+        self.pos_bar = positionbar.PositionBar(False)
+        self.pos_bar.set_listener(self.position_listener)
+        self.pos_bar.mouse_press_listener = self.pos_bar_press_listener
+        self.pos_bar.update_display_with_data(self.producer, -1, -1)
+
+        pos_bar_frame = Gtk.HBox()
+        pos_bar_frame.add(self.pos_bar.widget)
+        pos_bar_frame.set_margin_top(10)
+        pos_bar_frame.set_margin_bottom(9)
+        pos_bar_frame.set_margin_start(6)
+        pos_bar_frame.set_margin_end(2)
+                                                 
+                                                 
         control_panel = Gtk.HBox(False, 2)
-        control_panel.pack_start(self.frame_display, False, False, 0)
-        control_panel.pack_start(self.frame_select, False, False, 0)
-        control_panel.pack_start(Gtk.Label(), True, True, 0)
+        control_panel.pack_start(self.tc_display.widget, False, False, 0)
+        control_panel.pack_start(pos_bar_frame, True, True, 0)
         control_panel.pack_start(self.preview_button, False, False, 0)
         guiutils.set_margins(control_panel, 0, 24, 0, 0)
         
         self.editors_box = Gtk.HBox(False, 0)
-        self.editors_box.set_size_request(550, 185)
 
         self.import_select = Gtk.ComboBoxText()
         self.import_select.append_text(_("Add as Container Clip"))
         self.import_select.append_text(_("Add as Rendered Clip"))
         self.import_select.set_active(0)
         self.import_select.connect("changed", lambda w: self._export_action_changed(w))
-        import_row = guiutils.get_left_justified_box([Gtk.Label(label=_("Import Action:")), guiutils.pad_label(12,12), self.import_select])
+        import_row = guiutils.get_sides_justified_box([Gtk.Label(label=_("Import Action:")), guiutils.pad_label(12,12), self.import_select])
         guiutils.set_margins(import_row,8,0,0,0)
         self.length_spin = Gtk.SpinButton.new_with_range (25, 100000, 1)
         self.length_spin.set_value(200)
+        self.length_spin.connect("value-changed", self.lenght_value_changed)
+
         length_row = guiutils.get_left_justified_box([Gtk.Label(label=_("Generator Length:")), guiutils.pad_label(12,12), self.length_spin])
 
         self.encoding_button = Gtk.Button(label=_("Encode settings"))
@@ -326,16 +349,15 @@ class AddMediaPluginWindow(Gtk.Window):
         encoding_row = guiutils.get_left_justified_box([self.encoding_button, guiutils.pad_label(12,12), self.encoding_info])
                 
         right_column_panel = Gtk.VBox(False, 2)
-        right_column_panel.pack_start(screenshot_row, False, False, 0)
+        right_column_panel.pack_start(self.screenshot_canvas, True, True, 0)
         right_column_panel.pack_start(control_panel, False, False, 0)
         right_column_panel.pack_start(length_row, False, False, 0)
         right_column_panel.pack_start(import_row, False, False, 0)
         right_column_panel.pack_start(encoding_row, False, False, 0)
-        right_column_panel.pack_start(Gtk.Label(), True, True, 0)
 
         values_row = Gtk.HBox(False, 8)
         values_row.pack_start(self.editors_box, False, False, 0)
-        values_row.pack_start(right_column_panel, False, False, 0)
+        values_row.pack_start(right_column_panel, True, True, 0)
         
         close_button = guiutils.get_sized_button(_("Close"), 150, 32)
         close_button.connect("clicked", lambda w: _close_clicked())
@@ -350,7 +372,7 @@ class AddMediaPluginWindow(Gtk.Window):
 
         vbox = Gtk.VBox(False, 2)
         vbox.pack_start(plugin_select_row, False, False, 0)
-        vbox.pack_start(values_row, False, False, 0)
+        vbox.pack_start(values_row, True, True, 0)
         vbox.pack_start(buttons_row, False, False, 0)
         
         alignment = guiutils.set_margins(vbox, 8, 8, 12, 12)
@@ -391,19 +413,33 @@ class AddMediaPluginWindow(Gtk.Window):
         if _selected_plugin == None:
             return
 
-        cr.set_source_surface(_current_screenshot_surface, 0, 0)
+        mx, my, mw, mh = self._get_monitor_image_rect()
+        x, y, w, h = allocation
+
+        cr.rectangle(0, 0, w, h)
+        cr.set_source_rgb(0, 0, 0)
+        cr.fill()
+
+        scaled_surface = cairo.ImageSurface(cairo.FORMAT_ARGB32, int(mw), int(mh))
+        crs = cairo.Context(scaled_surface)
+        crs.save()
+        crs.scale(mw / _current_screenshot_surface.get_width(), mh / _current_screenshot_surface.get_height())
+        crs.set_source_surface(_current_screenshot_surface, 0, 0)
+        crs.paint()
+        crs.restore()
+    
+        cr.set_source_surface(scaled_surface, mx, my)
         cr.paint()
         
-        w, y, w, h = allocation
-        cr.set_source_rgb(0, 0, 0)
+        cr.set_source_rgb(0.2, 0.2, 0.2)
         cr.set_line_width(1.0)
-        cr.move_to(0.5, 0.5)
-        cr.line_to(w - 0.5, 0.5)
-        cr.line_to(w - 0.5, h - 0.5)
-        cr.line_to(0.5, h - 0.5)
-        cr.line_to(0.5, 0.5)
+        cr.move_to(mx + 0.5, my + 0.5)
+        cr.line_to(mx + mw - 0.5, my + 0.5)
+        cr.line_to(mx + mw - 0.5, my + mh - 0.5)
+        cr.line_to(mx + 0.5, my + mh - 0.5)
+        cr.line_to(mx + 0.5, my + 0.5)
         cr.stroke()
-                            
+        
     def _plugin_selection_changed(self, combo):
         name, new_selected_plugin = self.plugin_select.get_selected()
         
@@ -414,8 +450,15 @@ class AddMediaPluginWindow(Gtk.Window):
         global _selected_plugin, _current_screenshot_surface, _current_plugin_data_object
         _selected_plugin = new_selected_plugin
         _current_plugin_data_object = script_data_object
-        _current_screenshot_surface = self._create_preview_surface(new_selected_plugin.get_screenshot_surface())
-        
+        _current_screenshot_surface = new_selected_plugin.get_screenshot_surface()
+        self.length_spin.set_value(_current_plugin_data_object["length"])
+
+        self.producer.set_frame(0)
+        self.tc_display.set_frame(0)
+        self.producer.set_length(_current_plugin_data_object["length"])
+        self.pos_bar.update_display_with_data(self.producer, -1, -1)
+
+        self.pos_bar.widget.queue_draw()
         self.screenshot_canvas.queue_draw()
     
     def _show_plugin_editors_panel(self, script_data_object):
@@ -427,23 +470,46 @@ class AddMediaPluginWindow(Gtk.Window):
         
         self.editors_box.pack_start(self.plugin_editors.editors_panel, False, False, 0)
         self.show_all()
-
-    def _create_preview_surface(self, rendered_surface):
-        scaled_surface = cairo.ImageSurface(cairo.FORMAT_ARGB32, MONITOR_WIDTH, MONITOR_HEIGHT)
-        cr = cairo.Context(scaled_surface)
-        cr.save()
-        cr.scale(float(MONITOR_WIDTH) / float(rendered_surface.get_width()), float(MONITOR_HEIGHT) / float(rendered_surface.get_height()))
-        cr.set_source_surface(rendered_surface, 0, 0)
-        cr.paint()
-        cr.restore()
-
-        return scaled_surface
     
+    def _get_monitor_image_rect(self):
+        mw = self.screenshot_canvas.get_allocated_width()
+        mh = self.screenshot_canvas.get_allocated_height()
+        
+        canv_aspect = mw / mh
+        img_aspect = current_sequence().profile.width() / current_sequence().profile.height() 
+        
+        if canv_aspect > img_aspect:
+            y = 0
+            h = mh
+            w = h * img_aspect
+            x = mw / 2 - w / 2
+        else:
+            x = 0
+            w = mw
+            h = w / img_aspect
+            y = mh / 2 - h / 2 
+        
+        return (x, y, w, h)
+
+    def position_listener(self, normalized_pos, length):
+        frame = int(normalized_pos * length)
+        self.producer.set_frame(frame)
+        self.tc_display.set_frame(frame)
+        self.pos_bar.widget.queue_draw()
+
+    def pos_bar_press_listener(self):
+        pass #_player.stop_playback()
+
+    def lenght_value_changed(self, adjustment):
+        self.producer.set_length(adjustment.get_value())
+        self.pos_bar.update_display_with_data(self.producer, -1, -1)
+
+        self.pos_bar.widget.queue_draw()
+
     def _show_preview(self):
         global _selected_plugin, _current_screenshot_surface
-
-        fctx = self._render_preview(int(self.frame_select.get_value()))
-        _current_screenshot_surface = self._create_preview_surface(fctx.priv_context.frame_surface)
+        fctx = self._render_preview(int(self.producer.frame()))
+        _current_screenshot_surface = fctx.priv_context.frame_surface
 
         self.screenshot_canvas.queue_draw()
 
@@ -487,7 +553,7 @@ class AddMediaPluginWindow(Gtk.Window):
         container_data = containerclip.ContainerClipData(appconsts.CONTAINER_CLIP_FLUXITY, _selected_plugin.get_plugin_script_file(), None)
         container_data.data_slots["icon_file"] = None
         container_data.data_slots["fluxity_plugin_edit_data"] = _current_plugin_data_object
-        
+        #self.length_spin.set_value(_current_plugin_data_object["length"])
         containerclip.set_render_settings_from_create_window(container_data, self._encode_settings_done)
     
     def _encode_settings_done(self, render_data):
@@ -505,16 +571,37 @@ class AddMediaPluginWindow(Gtk.Window):
         else:
             self.encoding_info.set_markup("<small>" + _("Image Sequence") + "</small>")
             self.encoding_info.set_ellipsize(Pango.EllipsizeMode.END)
-        
 
+
+class PosBarProducer:
+    
+    def __init__(self):
+        self.length = 200
+        self.mark_in = -1
+        self.mark_out = -1
+        self.plugin_frame = 0
+        
+    def get_length(self):
+        return self.length
+
+    def set_length(self, length):
+        self.length = length
+        
+    def frame(self):
+        return self.plugin_frame
+
+    def set_frame(self, plugin_frame):
+        self.plugin_frame = plugin_frame
+        
 # ---------------------------------------------------------------------edit panel 
 def create_widgets():
     """
-    Widgets for editing compositing properties.
+    Widgets for editing generator properties.
     """
     widgets.plugin_info = guicomponents.PluginInfoPanel()
     widgets.hamburger_launcher = guicomponents.HamburgerPressLaunch(_hamburger_launch_pressed)
-    widgets.hamburger_launcher.connect_launched_menu(guicomponents.clip_effects_hamburger_menu)
+    widgets.hamburger_launcher.do_popover_callback = True
+    
     guiutils.set_margins(widgets.hamburger_launcher.widget, 4, 6, 6, 0)
     widgets.frame_select_box = Gtk.VBox()
     widgets.frame_select_button = None
@@ -526,7 +613,6 @@ def create_widgets():
     widgets.value_edit_box.pack_start(widgets.empty_label, True, True, 0)
     widgets.value_edit_frame = Gtk.Frame()
     widgets.value_edit_frame.add(widgets.value_edit_box)
-    widgets.value_edit_frame.set_shadow_type(Gtk.ShadowType.NONE)
 
 def get_plugin_hamburger_row():
     create_widgets()
@@ -659,11 +745,12 @@ def _apply():
     _action_object.apply_editors(_edit_panel.editor_widgets)
     _action_object.render_full_media(_clip)
 
-def _hamburger_launch_pressed(widget, event):
+def _hamburger_launch_pressed(launcher, widget, event, data):
     track, index = current_sequence().get_track_and_index_for_id(_clip.id)
-    guicomponents.get_media_plugin_editor_hamburger_menu(event, _hamburger_item_activated)
-
-def _hamburger_item_activated(widget, msg):
+    #guicomponents.get_media_plugin_editor_hamburger_menu(event, _hamburger_item_activated)
+    guipopover.plugin_editor_hamburger_popover_show(launcher, widget, _hamburger_item_activated)
+ 
+def _hamburger_item_activated(action, event, msg):
     if msg == "close":
         gui.editor_window.edit_multi.set_visible_child_name(appconsts.EDIT_MULTI_EMPTY)
     elif msg == "save_properties":
@@ -711,4 +798,4 @@ class PreviewCanvas:
 
     def _draw(self, event, cr, allocation):
         cr.set_source_surface(_preview_surface, 0, 0)
-        cr.paint()
\ No newline at end of file
+        cr.paint()
