@@ -4,7 +4,7 @@
     Flowblade Movie Editor is a nonlinear video editor.
     Copyright 2021 Janne Liljeblad.
 
-    This file is part of Flowblade Movie Editor <http://code.google.com/p/flowblade>.
+    This file is part of Flowblade Movie Editor <https://github.com/jliljebl/flowblade/>.
 
     Flowblade Movie Editor is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -52,7 +52,7 @@
     
     **`init_script(fctx):`** This method is called when script is first loaded by Flowblade to create data structures with info on editors and script metadata. 
     
-    **`init_render(fctx):`** This method is called before a render is started to get user input from editors, and possibly to create some additional data strctures.
+    **`init_render(fctx):`** This method is called before a render is started to get user input from editors, and possibly to create some additional data structures.
     
     **`render_frame(frame, fctx, w, h):`** This method is called for each rendered frame to create an output image.
     
@@ -83,7 +83,7 @@
         fctx.add_editor("Opacity", fluxity.EDITOR_INT_RANGE, (100, 5, 100))
         fctx.add_editor("Random Seed", fluxity.EDITOR_INT, 42)
     ```
-    In *init_script()* we define the editors that will be presented to the user and set some metadata like the name of the script diplayed to the user and the script author.
+    In *init_script()* we define the editors that will be presented to the user and set some metadata like the name of the script displayed to the user and the script author.
 
     ### init_render()
     ```
@@ -190,10 +190,17 @@
     
     **Flowblade** comes with a simple GUI tool for developing Fluxity scripts. It can be accessed from menu **Tools->Generator Script Editor**.
     
-    Using the development tool you can edit scripts, render output from them, and recieve error messages whenthings go wrong. From hamburger menu you can open and save your own scripts, access this document, and open and inspect example code from *Generators* distributed with Flowblade. 
+    Using the development tool you can edit scripts, render output from them, and receive error messages whenthings go wrong. From hamburger menu you can open and save your own scripts, access this document, and open and inspect example code from *Generators* distributed with Flowblade. 
     
     Since the text editor in the development tool is quite rudimentary, it can be a useful workflow to use an external text editor to edit the scripts, and press *Reload Script* button to update text area contents before attempting render.
     
+    ## FLUXITY API VERSIONS
+    
+    | VERSION | CHANGES |
+    |:--------|:--------|
+    | 1 | Initial release. |
+    | 2 | Added methods FluxityContext.required_api_version(), FluxityContext.add_editor_group() |
+
     # FLUXITY API
 """
 __pdoc__ = {}
@@ -361,6 +368,9 @@ KEYFRAME_SMOOTH = 1
 KEYFRAME_DISCRETE = 2
 """Value after keyframe of this type is value at keyframe."""
 
+API_VERSION = 2
+"""API version number, increasing integer for each Flowblade release with changes."""
+
 # ---------------------------------------------------------- script object
 class FluxityScript:
     """
@@ -422,7 +432,7 @@ class FluxityScript:
             _raise_fluxity_error("error calling function 'render_frame()':\n\n" + str(e))
 
 
-# ----------------------------------------------------------  Data structure correcponding with mlt.Profile
+# ----------------------------------------------------------  Data structure corresponding with mlt.Profile
 class FluxityProfile:
     """    
     Properties of this class correspond MLT profile objects.
@@ -453,6 +463,7 @@ class FluxityContext:
         self.script_file = script_file
         self.data = {}
         self.editors = {} # editors and script length
+        self.groups = {}
         self.editor_tooltips = {}
         self.length = DEFAULT_LENGTH
         self.name = "Name Not Set"
@@ -504,7 +515,6 @@ class FluxityContext:
         self.priv_context.error_on_wrong_method("set_name()", METHOD_INIT_SCRIPT)
         self.name = name
 
-
     def set_version(self, version):
         """
         **`version(int):`** version of script, use increasing integer numbering. Default value is *1*.
@@ -530,17 +540,17 @@ class FluxityContext:
 
     def set_data_obj(self, label, item):
         """
-        **`label(str):`** lable used to access data later using *`get_data_obj(self, label)`*.
+        **`label(str):`** label used to access data later using *`get_data_obj(self, label)`*.
 
         **`item(obj):`** data item being saved.
         
-        Saves data to be used later during execution of script. Using **global** would obivously be possible to replace this, but this is made available as a more clean solution.
+        Saves data to be used later during execution of script. Using **global** would obviously be possible to replace this, but this is made available as a more clean solution.
         """
         self.data[label] = item
 
     def get_data_obj(self, label):
         """
-        **`label(str):`** lable of saved data item.
+        **`label(str):`** label of saved data item.
         
         Gives access to previously saved data.
         
@@ -682,6 +692,7 @@ class FluxityContext:
 
         script_data["editors_list"] = editors_list # this is dict inside FluxityContext object, but is given out as list for convenience of Flowblade app integration.
         script_data["tooltips_list"] = self.editor_tooltips
+        script_data["groups_list"] = self.groups
         
         return json.dumps(script_data)
 
@@ -689,7 +700,7 @@ class FluxityContext:
         """             
         Returns path to directory where the script being executed is located.  
         
-        Sometimes script directory information is not available (e.g. when executing a non-saved script in Flowblade *Scrip Tool* application) and *None* is returned. It is recommeded that all Fluxity scripts handle getting *None* gracefully.
+        Sometimes script directory information is not available (e.g. when executing a non-saved script in Flowblade *Script Tool* application) and *None* is returned. It is recommended that all Fluxity scripts handle getting *None* gracefully.
         
         This functionality is useful when script is being distributed with some associated media files.
         
@@ -738,9 +749,9 @@ class FluxityContext:
 
     def create_text_layout(self, font_data):
         """
-        **`font_data(tuple)`** this tuple can be aquired by calling *FluxityContext.get_editor_value()* on editors of type *EDITOR_PANGO_FONT*.
+        **`font_data(tuple)`** this tuple can be acquired by calling *FluxityContext.get_editor_value()* on editors of type *EDITOR_PANGO_FONT*.
                 
-        Creates obejcts used to draw text.
+        Creates objects used to draw text.
 
         **Returns:** (fluxity.PangoTextLayout) object for drawing text.
         """
@@ -760,9 +771,35 @@ class FluxityContext:
                  
         Save output from 'print()' to file at given path. Must be called in script method *init_script()*.
         """
-        self.priv_context.error_on_wrong_method("add_editor()", METHOD_INIT_SCRIPT)
+        self.priv_context.error_on_wrong_method("set_prints_to_log_file()", METHOD_INIT_SCRIPT)
         _prints_to_log_file(log_file)
-    
+
+    def required_api_version(self, required_version):
+        """
+        **`required_version(int):`** Required API version for this script.
+                 
+        Raises error if API version too low. Must be called in script method *`init_script()`*.
+        """
+        self.priv_context.error_on_wrong_method("required_api_version()", METHOD_INIT_SCRIPT)
+        if required_version > API_VERSION:
+            _raise_fluxity_error("Fluxity API version too low for this script. Version " + str(required_version) + " required for this script, this system has Fluxity API version " + str(API_VERSION) + ".")
+
+    def add_editor_group(self, group_label):
+        """
+        **`group_label(str):`** Label for added group.
+                 
+        Adds editors group. All editors added after adding a group belong in that group until a new group ius added.
+        
+        If editor groups are used first one needs to be added before any editor. Must be called in script method *`init_script()`*.
+        """
+        self.priv_context.error_on_wrong_method("add_editor_group()", METHOD_INIT_SCRIPT)
+        if len(self.editors.keys()) > 0 and len(self.groups) == 0:
+            _raise_fluxity_error("If editor groups are used first one needs to be added before any editor.")
+
+        self.groups[len(self.editors.keys())] = group_label
+
+
+
 class FluxityContextPrivate:
     # This class exists to keep FluxityContext API clean for script developers.
     #
@@ -856,7 +893,7 @@ class FluxityEmptyClass:
 class PangoTextLayout:
 
     """
-    **`font_data(tuple)`** this tuple can be aquired by calling *`FluxityContext.get_editor_value()`* on editors of type *`EDITOR_PANGO_FONT`*.
+    **`font_data(tuple)`** this tuple can be acquired by calling *`FluxityContext.get_editor_value()`* on editors of type *`EDITOR_PANGO_FONT`*.
             
     Object for drawing text. Uses internally Pango.
     
@@ -875,7 +912,7 @@ class PangoTextLayout:
         
     def create_pango_layout(self, cr, text):
         """
-        **`cr(cairo.Context)`** frame cairo context aquired with *`FluxityContext.get_frame_cr()`*.
+        **`cr(cairo.Context)`** frame cairo context acquired with *`FluxityContext.get_frame_cr()`*.
         
         **`text(str)`** displayed text.
         
@@ -917,7 +954,7 @@ class PangoTextLayout:
         """             
         Returns size of layout.
 
-        Before calling this PangoCairo layout object needs to creted *`PangoTextLayout.create_pango_layout()`* or *`PangoTextLayout.draw_layout()`.*
+        Before calling this PangoCairo layout object needs to created *`PangoTextLayout.create_pango_layout()`* or *`PangoTextLayout.draw_layout()`.*
         
         **Returns:** (int, int)(width, height) pixel size of layout.
         """
@@ -943,7 +980,7 @@ class PangoTextLayout:
         
         **`text(str)`** displayed text.
         
-        **`cr(cairo.Context)`** frame cairo context aquired with *`FluxityContext.get_frame_cr()`*.
+        **`cr(cairo.Context)`** frame cairo context acquired with *`FluxityContext.get_frame_cr()`*.
         
         **`x(float)`** Text X position.
 
@@ -1094,13 +1131,13 @@ class AnimatedValue:
 
     def add_keyframe_at_frame(self, frame, value, kf_type):
         """
-        **`frame(int)`** Frame number in range 0 - (plugin lenght).
+        **`frame(int)`** Frame number in range 0 - (plugin length).
         
         **`value(float)`** A float value.
         
         **`kf_type(KEYFRAME_LINEAR|KEYFRAME_SMOOTH|KEYFRAME_DISCRETE)`** Type of added keyframe.
         
-        Adds or overwites a keyframe.
+        Adds or overwrites a keyframe.
                     
         If frame is on existing keyframe that keyframe is replaced.
         
@@ -1139,7 +1176,7 @@ class AnimatedValue:
         
     def get_value(self, frame):
         """
-        **`frame(int)`** Frame number in range 0 - (plugin lenght).
+        **`frame(int)`** Frame number in range 0 - (plugin length).
                 
         Computes and returns value at frame using current keyframe values, positions and types.
 
@@ -1209,7 +1246,7 @@ class AffineTransform:
     """
     Object for describing animated affine transforms and applying them on *`cairo.Context`*.
 
-    On creation object creates followig instance *`fluxity.AnimatedValue`* attributes:
+    On creation object creates following instance *`fluxity.AnimatedValue`* attributes:
      
     **`x`** X position in pixels.
     
@@ -1249,7 +1286,7 @@ class AffineTransform:
         """
         **`cr(cairo.Context)`** a `cairo.Context` object.
         
-        **`frame(int)`** Frame number in range 0 - (plugin lenght).
+        **`frame(int)`** Frame number in range 0 - (plugin length).
                 
         Applies affine transform defined by object instance at given frame on `cairo.Context` object.
         """
@@ -1307,7 +1344,7 @@ def render_preview_frame(script, script_file, frame, out_folder, profile_file_pa
     """
     **script(str)** Script to be rendered as a string.
     
-    **script_file(str)** Absolut path to file containing script. If this is not provided methods some like *FluxityContext.get_script_dir()* will not function as intended.
+    **script_file(str)** Absolute path to file containing script. If this is not provided methods some like *FluxityContext.get_script_dir()* will not function as intended.
     
     **frame(int)** Frame to be rendered in range 0 - *(script_length - 1)*.
     
@@ -1357,7 +1394,7 @@ def render_frame_sequence(script, script_file, in_frame, out_frame, out_folder,
     """
     **script(str)** Script to be rendered as a string.
     
-    **script_file(str)** Absolut path to file containing script. If this is not provided methods some like *FluxityContext.get_script_dir()* will not function as intended.
+    **script_file(str)** Absolute path to file containing script. If this is not provided methods some like *FluxityContext.get_script_dir()* will not function as intended.
     
     **in_frame(int)** First frame of rendered range.
 
@@ -1375,7 +1412,7 @@ def render_frame_sequence(script, script_file, in_frame, out_frame, out_folder,
     
     **Returns:** (dict) Dictionary object created during rendering with the following information:
     
-    * for each process it has *key -> value* pair *process number(str) -> path to first frame redered by process(str)*.
+    * for each process it has *key -> value* pair *process number(str) -> path to first frame rendered by process(str)*.
     * if errors occurred during rendering it has *key -> value* pair *fluxity.FLUXITY_ERROR_MSG -> error message(str)*.
     * if script created log messages it has *key -> value* pair *fluxity.FLUXITY_LOG_MSG -> log message(str)*.
     """
@@ -1470,7 +1507,7 @@ def get_script_default_edit_data(script, script_file, out_folder, profile_file_p
     """
     **script(str)** Script to be rendered as a string.
     
-    **script_file(str)** Absolut path to a file containing script. If this is not provided, some methods like *FluxityContext.get_script_dir()* will not function as intended.
+    **script_file(str)** Absolute path to a file containing script. If this is not provided, some methods like *FluxityContext.get_script_dir()* will not function as intended.
     
     **out_folder(str)** Path to the folder where rendered frame will be saved.
     
